/* ###################################################################
**     THIS COMPONENT MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename    : Tx3.h
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : RingBuffer
**     Version     : Component 01.041, Driver 01.00, CPU db: 3.00.000
**     Compiler    : GNU C Compiler
**     Date/Time   : 2015-11-08, 19:46, # CodeGen: 0
**     Abstract    :
**         This component implements a ring buffer for different integer data type.
**     Settings    :
**          Component name                                 : Tx3
**          Buffer Size                                    : 8
**     Contents    :
**         Clear           - void Tx3_Clear(void);
**         Put             - uint8_t Tx3_Put(Tx3_ElementType elem);
**         Get             - uint8_t Tx3_Get(Tx3_ElementType *elemP);
**         Peek            - uint8_t Tx3_Peek(Tx3_BufSizeType index, Tx3_ElementType *elemP);
**         Delete          - uint8_t Tx3_Delete(void);
**         NofElements     - Tx3_BufSizeType Tx3_NofElements(void);
**         NofFreeElements - Tx3_BufSizeType Tx3_NofFreeElements(void);
**         Deinit          - void Tx3_Deinit(void);
**         Init            - void Tx3_Init(void);
**
**     License   :  Open Source (LGPL)
**     Copyright : (c) Copyright Erich Styger, 2014-2015, all rights reserved.
**     Web: http://www.mcuoneclipse.com
**     This an open source software of an embedded component for Processor Expert.
**     This is a free software and is opened for education,  research  and commercial developments under license policy of following terms:
**     * This is a free software and there is NO WARRANTY.
**     * No restriction on use. You can use, modify and redistribute it for personal, non-profit or commercial product UNDER YOUR RESPONSIBILITY.
**     * Redistributions of source code must retain the above copyright notice.
** ###################################################################*/
/*!
** @file Tx3.h
** @version 01.00
** @brief
**         This component implements a ring buffer for different integer data type.
*/         
/*!
**  @addtogroup Tx3_module Tx3 module documentation
**  @{
*/         

#ifndef __Tx3_H
#define __Tx3_H

/* MODULE Tx3. */

/* Include shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"
/* Include inherited beans */
#include "CS1.h"

#include "Cpu.h"


#define Tx3_BUF_SIZE    8   /* number of elements in the buffer */
#define Tx3_ELEM_SIZE   4  /* size of a single element in bytes */
#define Tx3_IS_REENTRANT   1  /* 1: Critical section used for accessing shared data, 0 otherwise */
#if Tx3_ELEM_SIZE==1
  typedef uint8_t Tx3_ElementType; /* type of single element */
#elif Tx3_ELEM_SIZE==2
  typedef uint16_t Tx3_ElementType; /* type of single element */
#elif Tx3_ELEM_SIZE==4
  typedef uint32_t Tx3_ElementType; /* type of single element */
#else
  #error "illegal element type size in properties"
#endif
#if Tx3_BUF_SIZE<256
  typedef uint8_t Tx3_BufSizeType; /* up to 255 elements (index 0x00..0xff) */
#else
  typedef uint16_t Tx3_BufSizeType; /* more than 255 elements, up to 2^16 */
#endif

uint8_t Tx3_Put(Tx3_ElementType elem);
/*
** ===================================================================
**     Method      :  Tx3_Put (component RingBuffer)
**     Description :
**         Puts a new element into the buffer
**     Parameters  :
**         NAME            - DESCRIPTION
**         elem            - New element to be put into the buffer
**     Returns     :
**         ---             - Error code
** ===================================================================
*/

uint8_t Tx3_Get(Tx3_ElementType *elemP);
/*
** ===================================================================
**     Method      :  Tx3_Get (component RingBuffer)
**     Description :
**         Removes an element from the buffer
**     Parameters  :
**         NAME            - DESCRIPTION
**       * elemP           - Pointer to where to store the received
**                           element
**     Returns     :
**         ---             - Error code
** ===================================================================
*/

Tx3_BufSizeType Tx3_NofElements(void);
/*
** ===================================================================
**     Method      :  Tx3_NofElements (component RingBuffer)
**     Description :
**         Returns the actual number of elements in the buffer.
**     Parameters  : None
**     Returns     :
**         ---             - Number of elements in the buffer.
** ===================================================================
*/

void Tx3_Init(void);
/*
** ===================================================================
**     Method      :  Tx3_Init (component RingBuffer)
**     Description :
**         Initializes the data structure
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

Tx3_BufSizeType Tx3_NofFreeElements(void);
/*
** ===================================================================
**     Method      :  Tx3_NofFreeElements (component RingBuffer)
**     Description :
**         Returns the actual number of free elements/space in the
**         buffer.
**     Parameters  : None
**     Returns     :
**         ---             - Number of elements in the buffer.
** ===================================================================
*/

void Tx3_Clear(void);
/*
** ===================================================================
**     Method      :  Tx3_Clear (component RingBuffer)
**     Description :
**         Clear (empty) the ring buffer.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

uint8_t Tx3_Peek(Tx3_BufSizeType index, Tx3_ElementType *elemP);
/*
** ===================================================================
**     Method      :  Tx3_Peek (component RingBuffer)
**     Description :
**         Returns an element of the buffer without removiing it.
**     Parameters  :
**         NAME            - DESCRIPTION
**         index           - Index of element. 0 peeks the top
**                           element, 1 the next, and so on.
**       * elemP           - Pointer to where to store the received
**                           element
**     Returns     :
**         ---             - Error code
** ===================================================================
*/

#define Tx3_Deinit() \
   /* nothing to deinitialize */
/*
** ===================================================================
**     Method      :  Tx3_Deinit (component RingBuffer)
**     Description :
**         Driver de-initialization
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

uint8_t Tx3_Delete(void);
/*
** ===================================================================
**     Method      :  Tx3_Delete (component RingBuffer)
**     Description :
**         Removes an element from the buffer
**     Parameters  : None
**     Returns     :
**         ---             - Error code
** ===================================================================
*/

/* END Tx3. */

#endif
/* ifndef __Tx3_H */
/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.3 [05.09]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
